@@ -36,7 +36,7 @@ class Recipe(BaseSlapRecipe):
   def _install(self):
     self.parameter_dict = self.computer_partition.getInstanceParameterDict()
     software_type = self.parameter_dict.get('slap_software_type', 'kumo_cloud')
-    if software_type is None or software_type == 'root_instance':
+    if software_type is None or software_type == 'RootSoftwareInstance':
       software_type = 'kumo_cloud'
     if "run_%s" % software_type in dir(self) and \
        callable(getattr(self, "run_%s" % software_type)):
